==> stacked-1.2.2.tar.gz: lib/_viewmodel_builder_widget.dart <==
import 'package:flutter/cupertino.dart';

import '_viewmodel_builder.dart';

/// A widget that wraps the [ViewModelBuilder] class in a less boiler plate use of the widget
///
/// Default [reactive] value is true. Can be overriden and set to false
abstract class ViewModelBuilderWidget<T extends ChangeNotifier>
    extends StatelessWidget {
  const ViewModelBuilderWidget({Key key}) : super(key: key);

  /// A function that builds the UI to be shown from the ViewModel - Required
  ///
  /// [model] is the ViewModel passed in and [child] is the [staticChildBuilder] result
  Widget builder(
    BuildContext context,
    T model,
    Widget child,
  );

  /// A builder that builds the ViewModel for this UI - Required
  T viewModelBuilder();

  /// Indicates if the [builder] should be rebuilt when notifyListeners is called
  ///
  /// When reactive is false the builder will fire once and the widgets will be used
  /// as a static child. IT WILL NOT BE BUILT AGAIN.
  bool get reactive => true;

  /// When set to true a new ViewModel will be constructed everytime the widget is inserted.
  ///
  /// When setting this to true make sure to handle all disposing of streams if subscribed
  /// to any in the ViewModel. [onModelReady] will fire once the viewmodel has been created/set.
  /// This will be used when on re-insert of the widget the viewmodel has to be constructed with
  /// a new value.
  bool get createNewModelOnInsert => false;

  /// Indicates if you want Provider to dispose the viewmodel when it's removed from the widget tree.
  ///
  /// default's to true
  bool get disposeViewModel => true;

  /// Fires when the viewmodel is first created or re-created
  ///
  /// This will fire multiple times when [createNewModelOnInsert] is set to true
  void onViewModelReady(T model) {}

  /// A Function that builds UI for the static child that builds only once
  ///
  /// When [reactive] is set to false the builder is used as the static child
  /// and is only ever built once.
  Widget staticChildBuilder(BuildContext context) => null;

  @override
  Widget build(BuildContext context) {
    if (reactive) {
      return ViewModelBuilder<T>.reactive(
        builder: builder,
        viewModelBuilder: viewModelBuilder,
        staticChild:
            staticChildBuilder != null ? staticChildBuilder(context) : null,
        onModelReady: onViewModelReady,
        disposeViewModel: disposeViewModel,
        createNewModelOnInsert: createNewModelOnInsert,
      );
    } else {
      return ViewModelBuilder<T>.nonReactive(
        builder: builder,
        viewModelBuilder: viewModelBuilder,
        onModelReady: onViewModelReady,
        disposeViewModel: disposeViewModel,
        createNewModelOnInsert: createNewModelOnInsert,
      );
    }
  }
}

==> stacked-1.3.1.tar.gz: lib/_viewmodel_builder_widget.dart <==
import 'package:flutter/widgets.dart';

import '_viewmodel_builder.dart';

/// A widget that wraps the [ViewModelBuilder] class in a less boiler plate use of the widget
///
/// Default [reactive] value is true. Can be overriden and set to false
abstract class ViewModelBuilderWidget<T extends ChangeNotifier>
    extends StatelessWidget {
  const ViewModelBuilderWidget({Key key}) : super(key: key);

  /// A function that builds the UI to be shown from the ViewModel - Required
  ///
  /// [model] is the ViewModel passed in and [child] is the [staticChildBuilder] result
  Widget builder(
    BuildContext context,
    T model,
    Widget child,
  );

  /// A builder that builds the ViewModel for this UI - Required
  T viewModelBuilder(BuildContext context);

  /// Indicates if the [builder] should be rebuilt when notifyListeners is called
  ///
  /// When reactive is false the builder will fire once and the widgets will be used
  /// as a static child. IT WILL NOT BE BUILT AGAIN.
  bool get reactive => true;

  /// When set to true a new ViewModel will be constructed everytime the widget is inserted.
  ///
  /// When setting this to true make sure to handle all disposing of streams if subscribed
  /// to any in the ViewModel. [onModelReady] will fire once the viewmodel has been created/set.
  /// This will be used when on re-insert of the widget the viewmodel has to be constructed with
  /// a new value.
  bool get createNewModelOnInsert => false;

  /// Indicates if you want Provider to dispose the viewmodel when it's removed from the widget tree.
  ///
  /// default's to true
  bool get disposeViewModel => true;

  /// Fires when the viewmodel is first created or re-created
  ///
  /// This will fire multiple times when [createNewModelOnInsert] is set to true
  void onViewModelReady(T model) {}

  /// A Function that builds UI for the static child that builds only once
  ///
  /// When [reactive] is set to false the builder is used as the static child
  /// and is only ever built once.
  Widget staticChildBuilder(BuildContext context) => null;

  @override
  Widget build(BuildContext context) {
    if (reactive) {
      return ViewModelBuilder<T>.reactive(
        builder: builder,
        viewModelBuilder: () => viewModelBuilder(context),
        staticChild:
            staticChildBuilder != null ? staticChildBuilder(context) : null,
        onModelReady: onViewModelReady,
        disposeViewModel: disposeViewModel,
        createNewModelOnInsert: createNewModelOnInsert,
      );
    } else {
      return ViewModelBuilder<T>.nonReactive(
        builder: builder,
        viewModelBuilder: () => viewModelBuilder(context),
        onModelReady: onViewModelReady,
        disposeViewModel: disposeViewModel,
        createNewModelOnInsert: createNewModelOnInsert,
      );
    }
  }
}
